<?php

use function Skytec\write_log;

function getConst(string $name): false|string
{
    if (defined($name)) {
        $value = constant($name);
        if ($value === false || empty($value)) {
            throw new Exception("Empty or false environment variable: $name");
        }
        return $value;
    } else {
        throw new Exception("Missing environment variable: $name");
    }
}

function getHashSky(): false|string
{
    $sky_user = getConst('SKY_DB_USER');
    $sky_pass = getConst('SKY_DB_PASS');
    if (!$sky_user || !$sky_pass) {
        write_log("Missing username or password for Skytec");
        return false;
    }
    $url = "https://adminapi.easy-step.no/api/login";
    $data = array(
        'Username' => $sky_user,
        'Password' => $sky_pass,
        'Temp' => true
    );
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($data));
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    $response = curl_exec($ch);
    curl_close($ch);
    $response = json_decode($response);
    if ($response->status->code != 200) {
        return false;
    }
    return $response->items->Hash;
}

function getApiSky(string $endpoint, $parms = array()): false|object
{
    $hash = getHashSky();
    if (!$hash) {
        return false;
    }
    $base = "https://adminapi.easy-step.no/api";
    $parms['Hash'] = $hash;
    $parms['DBName'] = getConst('SKY_DB_NAME');
    $url = $base . $endpoint . '?' . http_build_query($parms);
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    $response = curl_exec($ch);
    curl_close($ch);
    $response = json_decode($response);
    if ($response->status->code != 200) {
        write_log("GET API SKY ERROR: $endpoint");
        write_log($response);
        return false;
    }
    return $response;
}

function postApiSky(string $endpoint, $data = array()): false|object
{
    $hash = getHashSky();
    $base = "https://adminapi.easy-step.no/api";
    $data['Hash'] = $hash;
    $data['DBName'] = getConst('SKY_DB_NAME');
    $url = $base . $endpoint;
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($data));
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    $response = curl_exec($ch);
    curl_close($ch);
    $response = json_decode($response);
    if ($response->status->code != 200) {
        write_log("GET API SKY ERROR: $endpoint");
        write_log($response);
        return false;
    }
    return $response;
}

function putApiSky(string $endpoint, $data = array()): false|object
{
    $hash = getHashSky();
    $base = "https://adminapi.easy-step.no/api";
    $data['Hash'] = $hash;
    $data['DBName'] = getConst('SKY_DB_NAME');
    $url = $base . $endpoint;
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_CUSTOMREQUEST, "PUT");
    curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($data));
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    $response = curl_exec($ch);
    curl_close($ch);
    $response = json_decode($response);
    if ($response->status->code != 200) {
        return false;
    }
    return $response;
}

function sky_get_products(): false|object
{
    $endpoint = "/articles";
    $parms = array(
        'VisibleOnWeb' => 1,
    );
    $response = getApiSky($endpoint, $parms);
    if (!$response) {
        write_log('Failed to get products from Skytec');
        return false;
    }
    return $response;
}

function sky_get_order($order_id): false|object
{
    $endpoint = "/orders";
    $parms = array(
        'OrderID' => $order_id,
    );
    $response = getApiSky($endpoint, $parms);
    if (!$response) {
        return false;
    }
    return $response->items[0];
}

function sky_get_stock($id): false|object
{
    $endpoint = "/getArticleStockV2";
    $parms = array(
        'ArticleNo' => $id,
    );
    $response = getApiSky($endpoint, $parms);
    if (!$response) {
        return false;
    }
    $item = $response->items[0];
    if (!$item) {
        return false;
    }
    return $item;
}

function createOrderSky($data): false|object
{
    $endpoint = "/orders";
    $response = postApiSky($endpoint, $data);

    if (!$response) {
        return false;
    }

    return $response;
}

function createOrderLinesSky($data): false|string
{
    $endpoint = "/orderlines_v2";
    $response = postApiSky($endpoint, $data);

    if (!$response) {
        return false;
    }

    return $response->status->status;
}

function getCustomerSky(string $cno): false|object
{
    $endpoint = "/customers";
    $parms = array(
        'CustomerNo' => $cno,
    );
    $response = getApiSky($endpoint, $parms);
    if (!$response) {
        return false;
    }
    $item = $response->items[0];
    if (!$item) {
        return false;
    }
    return $item;
}

function getCustomerByOrgNOSky(string $org): false|object
{
    $endpoint = "/customers";
    $parms = array(
        'CompanyNo' => $org,
    );
    $response = getApiSky($endpoint, $parms);
    if (!$response) {
        return false;
    }
    $item = $response->items[0];
    if (!$item) {
        return false;
    }
    return $item;
}

function createCustomerSky($data): false|object
{
    $endpoint = "/customers";

    $response = postApiSky($endpoint, $data);

    if (!$response || $response->status->code != 200) {
        return false;
    }
    return $response->items;
}

function updateCustomerSky($data): false|string
{
    $endpoint = "/customers";
    $response = putApiSky($endpoint, $data);

    if (!$response || $response->status->code != 200) {
        return false;
    }
    return $response->items;
}

function getCustomerByPhone(string $phone): false|object
{
    $endpoint = "/customers";
    $parms = array(
        'Telephone' => $phone,
    );
    $response = getApiSky($endpoint, $parms);
    if (!$response || $response->status->code != 200) {
        return false;
    }
    $item = $response->items[0];
    if (!$item) {
        return false;
    }
    return $item;
}