<?php

add_role(
    'skytec_business',
    'Skytec Business',
    array(
        'read' => true,
        'edit_posts' => false,
        'delete_posts' => false,
    )
);

function notify_customer($user_email)
{
    $to = $user_email;
    $subject = 'Din søknad er mottatt';
    $body = 'Din søknad om bedriftskonto hos Skytec er mottatt. Vi vil behandle søknaden så snart som mulig, og du vil motta en ny e-post når søknaden er feridg behandlet.';
    $headers = array('Content-Type: text/html; charset=UTF-8; From: Skytec <wp@skytec.no>');

    wp_mail($to, $subject, $body, $headers);
}

function notify_admin()
{
    $to = 'dag@skytec.no';
    $subject = 'Ny bedriftsbruker registrert';
    $body = 'En ny bedriftsbruker har registrert seg. Gå inn på https://skytec.no/wp-admin/admin.php?page=new-user-approve-admin for å godkjenne brukeren.';
    $headers = array('Content-Type: text/html; charset=UTF-8; From: Skytec <wp@skytec.no>');

    wp_mail($to, $subject, $body, $headers);
}

function register_business_wp()
{
    $token = $_POST['g-recaptcha-response'];

    if (!isset($token) || empty($token)) {
        return wp_redirect('/bedriftsbruker-error');
    }

    if (!sky_verify_recaptcha($token)) {
        return wp_redirect('/bedriftsbruker-error');
    }

    global $wpdb;

    $first_name = sanitize_text_field($_POST['first_name']);
    $last_name = sanitize_text_field($_POST['last_name']);
    $business_name = sanitize_text_field($_POST['business_name']);
    $org_number = sanitize_text_field(str_replace(' ', '', $_POST['org_number']));
    $user_email = sanitize_text_field($_POST['user_email']);
    $username = sanitize_text_field($_POST['user_email']);
    $user_phone = sanitize_text_field($_POST['user_phone']);
    $user_password = $_POST['user_password'];

    $business_exists_in_wp = $wpdb->get_var(
        $wpdb->prepare(
            "SELECT * FROM {$wpdb->prefix}usermeta WHERE meta_key = 'billing_org_number' AND meta_value = %s",
            $org_number
        )
    );

    if ($business_exists_in_wp) {
        return wp_redirect('/bedriftsbruker-eksisterer');
    }

    $user_id = wp_create_user($username, $user_password, $user_email);

    if (is_wp_error($user_id)) {
        return wp_redirect('/bedriftsbruker-error');
    }

    $user = new WP_User($user_id);

    $user->set_role('skytec_business');

    update_user_meta($user_id, 'pw_user_status', 'pending');
    update_user_meta($user_id, 'billing_phone', $user_phone);
    update_user_meta($user_id, 'first_name', $first_name);
    update_user_meta($user_id, 'last_name', $last_name);
    update_user_meta($user_id, 'billing_company', $business_name);
    update_user_meta($user_id, 'billing_org_number', $org_number);

    notify_customer($user_email);
    notify_admin();

    return wp_redirect('/bedriftsbruker-takk');
}

add_action('admin_post_nopriv_sky_business_registration', 'register_business_wp', 20, 3);

function register_business_sky($user)
{
    $user_id = $user->ID;
    $business_name = get_user_meta($user_id, 'billing_company', true);
    $org_number = get_user_meta($user_id, 'billing_org_number', true);
    $user_email = $user->user_email;
    $user_phone = get_user_meta($user_id, 'billing_phone', true);

    $business_exists = getCustomerByOrgNOSky($org_number);

    if (!$business_exists) {
        $data = array(
            'Name' => $business_name,
            'CompanyNo' => $org_number,
            'Telephone' => $user_phone,
            'Email' => $user_email,
        );

        $created_business = createCustomerSky($data);

        if ($created_business) {
            add_user_meta($user_id, 'sky_customer_id', $created_business->CustomerID, true);
        }
    }

    add_user_meta($user_id, 'sky_customer_id', $business_exists->CustomerID, true);
}

add_action('new_user_approve_user_approved', 'register_business_sky', 10, 1);