<?php

use function Skytec\write_log;

add_filter('cron_schedules', function ($schedules) {
    $schedules['half_hour'] = array(
        'interval' => 1800,
        'display' => __('Half hour')
    );
    return $schedules;
});

if (!wp_next_scheduled('dev_cron_hook')) {
    wp_schedule_event(time(), 'hourly', 'dev_cron_hook');
}

if (!wp_next_scheduled('dev_cron_hook_half_hour')) {
    wp_schedule_event(time(), 'half_hour', 'dev_cron_hook_half_hour');
}


function sync_from_skytec()
{
    $response = sky_get_products();
    if (!$response || !isset($response->items) || !is_array($response->items)) {
        write_log('Failed to get products from Skytec or invalid response structure');
        return;
    }

    $sky_products = $response->items;

    foreach ($sky_products as $sky_product) {
        if (!isset($sky_product->ArticleNo) || !isset($sky_product->ArticleID)) {
            write_log('Skytec product missing ArticleNo or ArticleID: ' . print_r($sky_product, true));
            continue;
        }

        $wc_product_id = wc_get_product_id_by_sku($sky_product->ArticleNo);
        $stock = sky_get_stock($sky_product->ArticleNo);

        if (!$wc_product_id) {
            $wc_product = new WC_Product_Simple();
            $wc_product->set_sku($sky_product->ArticleNo);
            $wc_product->set_name($sky_product->Name ?? '');
            $wc_product->set_regular_price($sky_product->SalesPrice ?? 0);
            if ($stock && isset($stock->StockQty)) {
                $wc_product->set_manage_stock(true);
                $wc_product->set_stock_quantity($stock->StockQty);
            }
            // Save both Skytec ArticleNo and ArticleID as custom meta
            $wc_product->update_meta_data('skytec_article_no', $sky_product->ArticleNo);
            $wc_product->update_meta_data('skytec_article_id', $sky_product->ArticleID);
            $wc_product->save();
        } else {
            $wc_product = wc_get_product($wc_product_id);
            $wc_product->set_sku($sky_product->ArticleNo);
            $wc_product->set_name($sky_product->Name ?? $wc_product->get_name());
            $wc_product->set_regular_price($sky_product->SalesPrice ?? $wc_product->get_regular_price());
            if ($stock && isset($stock->StockQty)) {
                $wc_product->set_manage_stock(true);
                $wc_product->set_stock_quantity($stock->StockQty);
            }
            // Update both Skytec ArticleNo and ArticleID as custom meta
            $wc_product->update_meta_data('skytec_article_no', $sky_product->ArticleNo);
            $wc_product->update_meta_data('skytec_article_id', $sky_product->ArticleID);
            $wc_product->save();
        }
    }
    write_log('Products synced from Skytec');
}

add_action('dev_cron_hook', 'sync_from_skytec');

function update_order_status()
{
    $orders = wc_get_orders(
        array(
            'limit' => -1,
            'status' => 'processing',
        )
    );

    write_log("Updating order status");

    foreach ($orders as $order) {
        write_log("foud order " . $order->get_id());
        // Use getter method instead of direct property access
        $order_id = $order->get_id();
        $sky_order_id = get_post_meta($order_id, 'sky_order_id', true);

        if (!$sky_order_id) {
            write_log("Order " . $order_id . " has no sky_order_id");
            continue;
        }

        $skyOrder = sky_get_order($sky_order_id);
        if (!$skyOrder) {
            write_log("Failed to get order " . $sky_order_id . " from Skytec");
            continue;  // Changed from return false to continue
        }

        write_log($skyOrder);

        if ($skyOrder->OrderTemplateID == 7) {
            write_log(log: "Order " . $order->get_id() . " is completed");
            $order->update_status('completed');
            $order->save();
        }
    }
}

add_action('dev_cron_hook_half_hour', 'update_order_status');