<?php

use function Skytec\write_log;

function send_order_to_sky($order_id)
{
    $order = wc_get_order($order_id);
    $user_id = $order->get_user_id();
    $sky_customer_id = get_user_meta($user_id, 'sky_customer_id', true);

    $orderlines = array();

    $shipping = array(
        'DeliveryName' => $order->get_billing_first_name() . ' ' . $order->get_billing_last_name(),
        'DeliveryAddress1' => $order->get_billing_address_1(),
        'DeliveryAddress2' => $order->get_billing_address_2(),
        'DeliveryZip' => $order->get_billing_postcode(),
        'DeliveryCity' => $order->get_billing_city(),
        'DeliveryPhone' => $order->get_billing_phone(),
    );

    if ($order->get_shipping_address_1() != '') {
        $shipping['DeliveryName'] = $order->get_shipping_first_name() . ' ' . $order->get_shipping_last_name();
        $shipping['DeliveryAddress1'] = $order->get_shipping_address_1();
        $shipping['DeliveryAddress2'] = $order->get_shipping_address_2();
        $shipping['DeliveryZip'] = $order->get_shipping_postcode();
        $shipping['DeliveryCity'] = $order->get_shipping_city();
    }

    foreach ($order->get_items() as $order_item) {
        $wc_product = wc_get_product($order_item->get_product_id());
        $skytec_article_id = $wc_product->get_meta('skytec_article_id');

        $item_quantity = $order_item->get_quantity();
        $item_price = $order_item->get_total() / $item_quantity;

        $item_discount_percentage = 0;
        if ($order_item->get_subtotal() > 0) {
            $item_discount_percentage = round(($order_item->get_subtotal() - $order_item->get_total()) / $order_item->get_subtotal() * 100, 2);
        }

        $orderlines[] = array(
            "ArticleID" => (int) $skytec_article_id,
            "Count" => number_format($item_quantity, 3, '.', ''),
            "Price" => number_format($item_price, 3, '.', ''),
            "Discount" => number_format($item_discount_percentage, 2, '.', ''),
        );
    }

    // Check if shipping is not free
    if ($order->get_shipping_total() > 0) {
        $shipping_net_amount = $order->get_shipping_total();

        $orderlines[] = array(
            "ArticleID" => 3545,
            "Count" => "1.000",
            "Price" => number_format($shipping_net_amount, 3, '.', ''),
            "Discount" => "0.00",
        );
    }

    $orderSky = array(
        'CustomerID' => (int) $sky_customer_id,
        'OrderType' => 2,
        'OrderTemplateID' => 4,
        'OrderLines' => $orderlines,
        'DeliveryName' => substr($shipping['DeliveryName'], 0, 50),
        'DeliveryAddress1' => $shipping['DeliveryAddress1'],
        'DeliveryAddress2' => $shipping['DeliveryAddress2'],
        'DeliveryZip' => $shipping['DeliveryZip'],
        'DeliveryCity' => $shipping['DeliveryCity'],
        'DeliveryPhone' => $shipping['DeliveryPhone'],
        'Info' => $order->get_customer_note(),
        'PLInfo' => strval($order->get_id()),
    );

    write_log("Sending order " . $order->get_id() . " to Skytec");
    write_log(json_encode($orderSky));

    $response = createOrderSky($orderSky);

    if ($response === false) {
        write_log("Failed to create order in Skytec: API call failed");
        return false;
    }

    if ($response->status->code != 200) {
        write_log("Failed to create order in Skytec: " . $response->status->status);
        return false;
    }

    if (!isset($response->items->OrderID->OrderID)) {
        write_log("Failed to create order in Skytec: OrderID not found in response");
        return false;
    }

    $sky_order_id = $response->items->OrderID->OrderID;

    if (!$sky_order_id) {
        write_log("Failed to create order in Skytec: OrderID not found in response");
        return false;
    }

    // Set order id as order meta
    update_post_meta($order->get_id(), 'sky_order_id', $sky_order_id);

    write_log("Order " . $order->get_id() . " successfully sent to Skytec with ID " . $sky_order_id);
}

add_action('woocommerce_order_status_processing', 'send_order_to_sky', 20, 1);


function update_sky_customer_address()
{
    $user_id = get_current_user_id();
    $sky_customer_id = get_user_meta($user_id, 'sky_customer_id', true);
    $first_name = get_user_meta($user_id, 'billing_first_name', true);
    $last_name = get_user_meta($user_id, 'billing_last_name', true);
    $email = get_user_meta($user_id, 'billing_email', true);
    $billing_address = get_user_meta($user_id, 'billing_address_1', true);
    $billing_postcode = get_user_meta($user_id, 'billing_postcode', true);
    $billing_city = get_user_meta($user_id, 'billing_city', true);
    $billing_phone = get_user_meta($user_id, 'billing_phone', true);

    $data = array(
        'CustomerID' => $sky_customer_id,
        'Name' => $first_name . ' ' . $last_name,
        'Email' => $email,
        'Telephone' => $billing_phone,
        'MailingAddress' => $billing_address,
        'MailingZip' => $billing_postcode,
        'MailingCity' => $billing_city,
    );

    updateCustomerSky($data);
}

add_action('woocommerce_after_edit_account_address_form', 'update_sky_customer_address', 20, 1);